@@ -1,11 +1,21 @@
 mod kucoin_spot;
 mod kucoin_swap;
+mod message;
 
 use crypto_market_type::MarketType;
 
 use crate::{OrderBookMsg, TradeMsg};
 
-use serde_json::Result;
+use serde_json::{Result, Value};
+
+use self::message::WebsocketMsg;
+
+pub(crate) fn extract_symbol(_market_type: MarketType, msg: &str) -> Option<String> {
+    let ws_msg = serde_json::from_str::<WebsocketMsg<Value>>(msg).unwrap();
+    let pos = ws_msg.topic.rfind(':').unwrap();
+    let symbol = &ws_msg.topic[pos + 1..];
+    Some(symbol.to_string())
+}
 
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     if market_type == MarketType::Spot {
